==> hx_components_flutter-1.0.0.tar.gz: example/lib/example_view.dart <==
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_components.dart';
import 'package:hx_components_flutter/hx_models.dart';

class ExampleView extends StatefulWidget {
  const ExampleView({super.key});

  @override
  State<ExampleView> createState() => _ExampleViewState();
}

class _ExampleViewState extends State<ExampleView> {
  final textController1 = TextEditingController();
  final textController2 = TextEditingController();
  final textController3 = TextEditingController();
  dynamic _groupValue = 4;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(8.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            mainAxisAlignment: MainAxisAlignment.start,
            children: [
              HxText.heading1('Heading 1'),
              HxText.heading1('Heading 1', fontWeight: FontWeight.normal),
              HxText.heading2('Heading 2'),
              HxText.heading2('Heading 2', fontWeight: FontWeight.normal),
              HxText.heading3('Heading 3'),
              HxText.heading3('Heading 3', fontWeight: FontWeight.normal),
              HxText.heading4('Heading 4'),
              HxText.heading4('Heading 4', fontWeight: FontWeight.normal),
              HxText.body('Body'),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxButton(
                      title: 'Toast Sucesso',
                      onTap: () {
                        HxToast.sucesso(context, 'Ação realizada com sucesso!');
                      }),
                  const SizedBox(width: 5.0),
                  HxButton.secondary(
                      title: 'Toast Erro',
                      onTap: () {
                        HxToast.erro(context, 'Tivemos problemas na sua requisição. Por favor tente novamente.');
                      }),
                  const SizedBox(width: 5.0),
                ],
              ),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxButton(
                      title: 'Alert Dialog',
                      onTap: () {
                        showDialog(
                          context: context,
                          builder: (context) {
                            return const HxAlertDialog(
                              titulo: 'Confirmar',
                              mensagem: 'Deseja realmente confirmar esta ação?',
                              textoBotaoConfirmar: 'Confirmar',
                              textoBotaoCancelar: 'Cancelar',
                            );
                          },
                        );
                      }),
                ],
              ),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxButton(title: 'HxButton', onTap: () {}),
                  const SizedBox(width: 5.0),
                  HxButton.secondary(title: 'HxButton', onTap: () {}, prefixIcon: Icons.check),
                  const SizedBox(width: 5.0),
                  HxButton(title: 'HxButton', onTap: () {}, prefixIcon: Icons.check, isLoading: true),
                ],
              ),
              const SizedBox(height: 5.0),
              Row(
                children: [
                  HxButton(title: 'HxButton'),
                  const SizedBox(width: 5.0),
                  HxButton.secondary(title: 'HxButton', prefixIcon: Icons.check),
                  const SizedBox(width: 5.0),
                  HxButton.secondary(title: 'HxButton', prefixIcon: Icons.check, isLoading: true),
                ],
              ),
              const Divider(),
              const SizedBox(height: 5.0),
              Row(
                children: [
                  HxButton.secondary(title: 'HxButton', onTap: () {}, isSmallButton: true),
                  const SizedBox(width: 5.0),
                  HxButton(title: 'HxButton', onTap: () {}, prefixIcon: Icons.check, isSmallButton: true),
                  const SizedBox(width: 5.0),
                  HxButton.secondary(title: 'HxButton', onTap: () {}, prefixIcon: Icons.check, isLoading: true, isSmallButton: true),
                ],
              ),
              const SizedBox(height: 5.0),
              Row(
                children: [
                  HxButton.secondary(title: 'HxButton', isSmallButton: true),
                  const SizedBox(width: 5.0),
                  HxButton(title: 'HxButton', prefixIcon: Icons.check, isSmallButton: true),
                  const SizedBox(width: 5.0),
                  HxButton(title: 'HxButton', prefixIcon: Icons.check, isSmallButton: true, isLoading: true),
                ],
              ),
              const SizedBox(height: 5.0),
              const Divider(),
              Row(
                children: [
                  HxButton(prefixIcon: Icons.add_box, onTap: () {}, isSmallButton: true),
                  const SizedBox(width: 10.0),
                  HxButton.secondary(prefixIcon: Icons.add_box, onTap: () {}, isSmallButton: true),
                  const SizedBox(width: 10.0),
                  HxOutlineButton(prefixIcon: Icons.add_box, onTap: () {}, isSmallButton: true),
                  const SizedBox(width: 10.0),
                  const HxOutlineButton(prefixIcon: Icons.add_box, isSmallButton: true),
                  const SizedBox(width: 10.0),
                  HxButton(prefixIcon: Icons.add_box, isSmallButton: true),
                ],
              ),
              const Divider(),
              Row(
                children: [
                  HxOutlineButton(title: 'Outline', onTap: () {}, prefixIcon: Icons.outbond_outlined),
                  const SizedBox(width: 5.0),
                  HxOutlineButton(title: 'Outline', onTap: () {}),
                  const SizedBox(width: 5.0),
                  HxOutlineButton(title: 'Outline', onTap: () {}, isLoading: true),
                ],
              ),
              const SizedBox(height: 5.0),
              Row(
                children: [
                  HxOutlineButton(title: 'Outline', onTap: () {}, prefixIcon: Icons.outbond_outlined, isSmallButton: true),
                  const SizedBox(width: 5.0),
                  HxOutlineButton(title: 'Outline', onTap: () {}, isSmallButton: true),
                  const SizedBox(width: 5.0),
                  HxOutlineButton(title: 'Outline', onTap: () {}, isLoading: true, isSmallButton: true),
                ],
              ),
              const SizedBox(height: 5.0),
              const Divider(),
              HxButton(title: 'HxButton ', onTap: () {}, wrapAroundContent: false),
              const SizedBox(height: 5.0),
              HxButton(title: 'HxButton ', onTap: () {}, wrapAroundContent: false, isLoading: true),
              const SizedBox(height: 5.0),
              HxButton.secondary(prefixIcon: Icons.person, wrapAroundContent: false, onTap: () {}),
              const SizedBox(height: 5.0),
              HxButton.secondary(prefixIcon: Icons.person, wrapAroundContent: false, onTap: () {}, isSmallButton: true),
              const SizedBox(height: 5.0),
              HxOutlineButton(title: 'HxButton ', prefixIcon: Icons.person, onTap: () {}, wrapAroundContent: false),
              const SizedBox(height: 5.0),
              HxButton.secondary(title: 'HxButton ', wrapAroundContent: false, isSmallButton: true),
              Row(
                children: <Widget>[
                  HxCardButton(
                    homeNavigation: () {},
                    title: 'Heading 3',
                    icon: Icons.person,
                  ),
                  HxCardButton(
                    homeNavigation: () {},
                    title: 'Heading 3',
                    icon: Icons.warning,
                  ),
                ],
              ),
              HxListItem.white(
                title: 'Heading 2',
                onTap: () {},
                icon: Icons.back_hand,
              ),
              const SizedBox(height: 5.0),
              HxListItem.blue(
                title: 'Heading 2',
                onTap: () {},
                icon: Icons.cached,
              ),
              const SizedBox(height: 5.0),
              HxListItem.white(
                title: 'Heading 2',
                description: 'Body',
                onTap: () {},
                icon: Icons.dark_mode,
              ),
              const SizedBox(height: 5.0),
              HxListItem.blue(
                title: 'Heading 2',
                description: 'Body',
                onTap: () {},
                icon: Icons.arrow_forward_ios,
              ),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxCheckbox.light(
                    value: true,
                    label: 'Body',
                  ),
                  const SizedBox(width: 10.0),
                  HxCheckbox.light(
                    value: false,
                    label: 'HxCheckbox',
                  ),
                ],
              ),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxCheckbox.dark(
                    value: false,
                    label: 'Body',
                  ),
                  const SizedBox(width: 10.0),
                  HxCheckbox.dark(
                    value: true,
                    label: 'HxCheckbox',
                  ),
                ],
              ),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxRadioButton.light(
                    label: 'Radio1',
                    value: 1,
                    groupValue: _groupValue,
                    onChanged: _handleRadioValueChange,
                  ),
                  const SizedBox(width: 10.0),
                  HxRadioButton.light(
                    label: 'Radio2',
                    toggleable: false,
                    value: 2,
                    groupValue: _groupValue,
                    onChanged: _handleRadioValueChange,
                  ),
                ],
              ),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxRadioButton.dark(
                    label: 'Radio3',
                    value: 3,
                    groupValue: _groupValue,
                    onChanged: _handleRadioValueChange,
                  ),
                  const SizedBox(width: 10.0),
                  HxRadioButton.dark(
                    label: 'Radio4',
                    value: 4,
                    groupValue: _groupValue,
                    onChanged: _handleRadioValueChange,
                  ),
                ],
              ),
              const SizedBox(height: 10.0),
              Row(
                children: <Widget>[
                  const HxChip(title: 'Body'),
                  const SizedBox(width: 10.0),
                  HxChip(
                    title: 'OnTap - HxChip',
                    onTap: () {},
                  ),
                  const SizedBox(width: 10.0),
                  const HxChip(title: 'HexagonProLib'),
                ],
              ),
              const SizedBox(height: 10.0),
              HxTextInput(
                controller: textController1,
                label: 'HxTextInput',
                textFieldType: TextFieldType.text,
              ),
              const SizedBox(height: 10.0),
              HxTextInput(
                controller: textController2,
                label: 'HxTextInput - Email',
                textFieldType: TextFieldType.email,
                initialValue: 'HxEmail@hexagon.pro',
              ),
              const SizedBox(height: 10.0),
              HxTextInput(
                controller: textController3,
                label: 'HxTextInput - Password',
                textFieldType: TextFieldType.password,
                initialValue: 'Hx1234',
              ),
              const SizedBox(height: 10.0),
              HxDropdownSearch<String>(
                items: const [
                  'Brazil',
                  'Italia',
                  'Tunisia',
                  'Canada',
                  'USA',
                ],
                label: 'Teste Normal',
                onChanged: (p0) {
                  debugPrint(p0);
                },
              ),
              const SizedBox(height: 10.0),
              HxDropdownSearch<String>.async(
                label: 'Teste Async',
                onChanged: (p0) {
                  debugPrint(p0);
                },
                asyncItems: (p0) async {
                  await Future.delayed(const Duration(seconds: 2));
                  return [
                    'Brazil',
                    'Italia',
                    'Tunisia',
                    'Canada',
                    'USA',
                  ];
                },
              ),
              const SizedBox(height: 10.0),
              const HxGradientBg(height: 200),
              const SizedBox(height: 10.0),
              const HxAnimatedBg(height: 200),
            ],
          ),
        ),
      ),
    );
  }

  void _handleRadioValueChange(value) {
    setState(() {
      _groupValue = value;
    });
  }
}

==> hx_components_flutter-1.0.2.tar.gz: example/lib/example_view.dart <==
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_components.dart';
import 'package:hx_components_flutter/hx_models.dart';

class ExampleView extends StatefulWidget {
  const ExampleView({super.key});

  @override
  State<ExampleView> createState() => _ExampleViewState();
}

class _ExampleViewState extends State<ExampleView> {
  final textController1 = TextEditingController();
  final textController2 = TextEditingController();
  final textController3 = TextEditingController();
  dynamic _groupValue = 4;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(8.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            mainAxisAlignment: MainAxisAlignment.start,
            children: [
              const HxCurvedAppBar.login(),
              const HxCurvedAppBar.menu(versionWidget: HxDeveloperStatusAppVersion()),
              HxText.heading1('Heading 1'),
              HxText.heading1('Heading 1', fontWeight: FontWeight.normal),
              HxText.heading2('Heading 2'),
              HxText.heading2('Heading 2', fontWeight: FontWeight.normal),
              HxText.heading3('Heading 3'),
              HxText.heading3('Heading 3', fontWeight: FontWeight.normal),
              HxText.heading4('Heading 4'),
              HxText.heading4('Heading 4', fontWeight: FontWeight.normal),
              HxText('Body'),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxButton.primary(
                      title: 'Toast Sucesso',
                      onTap: () {
                        HxToast.sucesso(context, 'Ação realizada com sucesso!');
                      }),
                  const SizedBox(width: 5.0),
                  HxButton.secondary(
                      title: 'Toast Erro',
                      onTap: () {
                        HxToast.erro(context, 'Tivemos problemas na sua requisição. Por favor tente novamente.');
                      }),
                  const SizedBox(width: 5.0),
                ],
              ),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxButton.primary(
                      title: 'Alert Dialog',
                      onTap: () {
                        showDialog(
                          context: context,
                          builder: (context) {
                            return const HxAlertDialog(
                              titulo: 'Confirmar',
                              mensagem: 'Deseja realmente confirmar esta ação?',
                              textoBotaoConfirmar: 'Confirmar',
                              textoBotaoCancelar: 'Cancelar',
                            );
                          },
                        );
                      }),
                ],
              ),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxButton.primary(title: 'HxButton', onTap: () {}),
                  const SizedBox(width: 5.0),
                  HxButton.secondary(title: 'HxButton', onTap: () {}, prefixIcon: Icons.check),
                  const SizedBox(width: 5.0),
                  HxButton.primary(title: 'HxButton', onTap: () {}, prefixIcon: Icons.check, isLoading: true),
                ],
              ),
              const SizedBox(height: 5.0),
              Row(
                children: [
                  HxButton.primary(
                    title: 'HxButton',
                    onTap: () {},
                  ),
                  const SizedBox(width: 5.0),
                  HxButton.secondary(title: 'HxButton', prefixIcon: Icons.check),
                  const SizedBox(width: 5.0),
                  HxButton.secondary(title: 'HxButton', prefixIcon: Icons.check, isLoading: true),
                ],
              ),
              const Divider(),
              const SizedBox(height: 5.0),
              Row(
                children: [
                  HxButton.secondary(title: 'HxButton', onTap: () {}, densidade: VisualDensity.compact),
                  const SizedBox(width: 5.0),
                  HxButton.primary(title: 'HxButton', onTap: () {}, prefixIcon: Icons.check, densidade: VisualDensity.compact),
                  const SizedBox(width: 5.0),
                  HxButton.secondary(title: 'HxButton', onTap: () {}, prefixIcon: Icons.check, isLoading: true, densidade: VisualDensity.compact),
                ],
              ),
              const SizedBox(height: 5.0),
              Row(
                children: [
                  HxButton.secondary(
                    title: 'HxButton',
                    densidade: VisualDensity.compact,
                  ),
                  const SizedBox(width: 5.0),
                  HxButton.primary(
                    title: 'HxButton',
                    prefixIcon: Icons.check,
                    densidade: VisualDensity.compact,
                    onTap: () {
                      print('tap');
                    },
                  ),
                  const SizedBox(width: 5.0),
                  HxButton.primary(
                    title: 'HxButton',
                    prefixIcon: Icons.check,
                    densidade: VisualDensity.compact,
                    isLoading: true,
                    onTap: () {
                      print('tap');
                    },
                  ),
                ],
              ),
              const SizedBox(height: 5.0),
              const Divider(),
              Row(
                children: [
                  HxButton.primaryIcon(prefixIcon: Icons.add_box, onTap: () {}),
                  const SizedBox(width: 10.0),
                  HxButton.secondaryIcon(prefixIcon: Icons.add_box, onTap: () {}),
                  const SizedBox(width: 10.0),
                  HxOutlineButton.icon(
                    prefixIcon: Icons.add_box,
                    onTap: () {},
                  ),
                  const SizedBox(width: 10.0),
                  HxOutlineButton.icon(
                    onTap: () {},
                    prefixIcon: Icons.add_box,
                    densidade: VisualDensity.compact,
                  ),
                  const SizedBox(width: 10.0),
                ],
              ),
              const Divider(),
              Row(
                children: [
                  HxOutlineButton(title: 'Outline', onTap: () {}, prefixIcon: Icons.outbond_outlined),
                  const SizedBox(width: 5.0),
                  HxOutlineButton(title: 'Outline', onTap: () {}),
                  const SizedBox(width: 5.0),
                  HxOutlineButton(title: 'Outline', onTap: () {}, isLoading: true),
                ],
              ),
              const SizedBox(height: 5.0),
              Row(
                children: [
                  HxOutlineButton(
                    title: 'Outline',
                    onTap: () {},
                    prefixIcon: Icons.outbond_outlined,
                    densidade: VisualDensity.compact,
                  ),
                  const SizedBox(width: 5.0),
                  HxOutlineButton(
                    title: 'Outline',
                    onTap: () {},
                    densidade: VisualDensity.compact,
                  ),
                  const SizedBox(width: 5.0),
                  HxOutlineButton(
                    title: 'Outline',
                    onTap: () {},
                    isLoading: true,
                    densidade: VisualDensity.compact,
                  ),
                ],
              ),
              const SizedBox(height: 5.0),
              const Divider(),
              HxButton.primary(
                title: 'HxButton ',
                onTap: () {},
                width: double.maxFinite,
              ),
              const SizedBox(height: 5.0),
              HxButton.primary(
                title: 'HxButton ',
                onTap: () {},
                isLoading: true,
                width: double.maxFinite,
              ),
              const SizedBox(height: 5.0),
              HxButton.secondary(
                prefixIcon: Icons.person,
                onTap: () {},
                width: double.maxFinite,
              ),
              const SizedBox(height: 5.0),
              HxButton.secondary(
                prefixIcon: Icons.person,
                onTap: () {},
                width: double.maxFinite,
                densidade: VisualDensity.compact,
              ),
              const SizedBox(height: 5.0),
              HxOutlineButton(title: 'HxButton ', prefixIcon: Icons.person, onTap: () {}, width: double.maxFinite),
              const SizedBox(height: 5.0),
              HxButton.secondary(
                title: 'HxButton ',
                width: double.maxFinite,
              ),
              Row(
                children: <Widget>[
                  HxCardButton(
                    homeNavigation: () {},
                    title: 'Heading 3',
                    icon: Icons.person,
                  ),
                  HxCardButton(
                    homeNavigation: () {},
                    title: 'Heading 3',
                    icon: Icons.warning,
                  ),
                ],
              ),
              HxListItem.white(
                title: 'Heading 2',
                onTap: () {},
                icon: Icons.back_hand,
              ),
              const SizedBox(height: 5.0),
              HxListItem.blue(
                title: 'Heading 2',
                onTap: () {},
                icon: Icons.cached,
              ),
              const SizedBox(height: 5.0),
              HxListItem.white(
                title: 'Heading 2',
                description: 'Body',
                onTap: () {},
                icon: Icons.dark_mode,
              ),
              const SizedBox(height: 5.0),
              HxListItem.blue(
                title: 'Heading 2',
                description: 'Body',
                onTap: () {},
                icon: Icons.arrow_forward_ios,
              ),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxCheckbox.light(
                    value: true,
                    label: 'Body',
                  ),
                  const SizedBox(width: 10.0),
                  HxCheckbox.light(
                    value: false,
                    label: 'HxCheckbox',
                  ),
                ],
              ),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxCheckbox.dark(
                    value: false,
                    label: 'Body',
                  ),
                  const SizedBox(width: 10.0),
                  HxCheckbox.dark(
                    value: true,
                    label: 'HxCheckbox',
                  ),
                ],
              ),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxRadioButton.light(
                    label: 'Radio1',
                    value: 1,
                    groupValue: _groupValue,
                    onChanged: _handleRadioValueChange,
                  ),
                  const SizedBox(width: 10.0),
                  HxRadioButton.light(
                    label: 'Radio2',
                    toggleable: false,
                    value: 2,
                    groupValue: _groupValue,
                    onChanged: _handleRadioValueChange,
                  ),
                ],
              ),
              const SizedBox(height: 10.0),
              Row(
                children: [
                  HxRadioButton.dark(
                    label: 'Radio3',
                    value: 3,
                    groupValue: _groupValue,
                    onChanged: _handleRadioValueChange,
                  ),
                  const SizedBox(width: 10.0),
                  HxRadioButton.dark(
                    label: 'Radio4',
                    value: 4,
                    groupValue: _groupValue,
                    onChanged: _handleRadioValueChange,
                  ),
                ],
              ),
              const SizedBox(height: 10.0),
              Row(
                children: <Widget>[
                  const HxChip(title: 'Body'),
                  const SizedBox(width: 10.0),
                  HxChip(
                    title: 'OnTap - HxChip',
                    onTap: () {},
                  ),
                  const SizedBox(width: 10.0),
                  const HxChip(title: 'HexagonProLib'),
                ],
              ),
              const SizedBox(height: 10.0),
              HxTextInput(
                controller: textController1,
                label: 'HxTextInput',
                textFieldType: TextFieldType.text,
              ),
              const SizedBox(height: 10.0),
              HxTextInput(
                controller: textController2,
                label: 'HxTextInput - Email',
                textFieldType: TextFieldType.email,
                initialValue: 'HxEmail@hexagon.pro',
              ),
              const SizedBox(height: 10.0),
              HxTextInput(
                controller: textController3,
                label: 'HxTextInput - Password',
                textFieldType: TextFieldType.password,
                initialValue: 'Hx1234',
              ),
              const SizedBox(height: 10.0),
              HxDropdownSearch<String>(
                items: const [
                  'Brazil',
                  'Italia',
                  'Tunisia',
                  'Canada',
                  'USA',
                ],
                label: 'Teste Normal',
                onChanged: (p0) {
                  debugPrint(p0);
                },
              ),
              const SizedBox(height: 10.0),
              HxDropdownSearch<String>.async(
                label: 'Teste Async',
                onChanged: (p0) {
                  debugPrint(p0);
                },
                asyncItems: (p0) async {
                  await Future.delayed(const Duration(seconds: 2));
                  return [
                    'Brazil',
                    'Italia',
                    'Tunisia',
                    'Canada',
                    'USA',
                  ];
                },
              ),
              const SizedBox(height: 10.0),
              const HxGradientBg(height: 200),
              const SizedBox(height: 10.0),
              const HxAnimatedBg(height: 200),
            ],
          ),
        ),
      ),
    );
  }

  void _handleRadioValueChange(value) {
    setState(() {
      _groupValue = value;
    });
  }
}
